@@ -39,6 +39,8 @@
 #include <Kdelibs4ConfigMigrator>
 #include <KLocalizedString>
 
+#include <iostream>
+
 using Kerfuffle::AddToArchive;
 
 class OpenFileEventHandler : public QObject
@@ -68,13 +70,14 @@ private:
 
 int main(int argc, char **argv)
 {
-    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts); // Required for the webengine part.
-    QApplication application(argc, argv);
-
     /**
      * enable high dpi support
      */
-    application.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+
+    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts); // Required for the webengine part.
+    QApplication application(argc, argv);
 
     KCrash::initialize();
 
@@ -191,7 +194,7 @@ int main(int argc, char **argv)
                                         i18n("The destination argument will be set to the path of the first file supplied.")));
 
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("a") << QStringLiteral("autosubfolder"),
-                                        i18n("Archive contents will be read, and if detected to not be a single folder archive, a subfolder with the name of the archive will be created.")));
+                                        i18n("Archive contents will be read, and if detected to not be a single folder or a single file archive, a subfolder with the name of the archive will be created.")));
 
     parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("m") << QStringLiteral("mimetypes"),
                                         i18n("List supported MIME types.")));
@@ -227,6 +230,11 @@ int main(int argc, char **argv)
         if (parser.isSet(QStringLiteral("add")) ||
             parser.isSet(QStringLiteral("add-to"))) {
 
+            if (urls.isEmpty()) {
+                std::cout << "Missing arguments: urls." << std::endl;
+                parser.showHelp(-1);
+            }
+
             AddToArchive *addToArchiveJob = new AddToArchive(&application);
             application.setQuitOnLastWindowClosed(false);
             QObject::connect(addToArchiveJob, &KJob::result, &application, &QCoreApplication::quit, Qt::QueuedConnection);
