@@ -62,10 +62,12 @@ class Archive::Entry : public QObject
     Q_PROPERTY(QString link MEMBER m_link)
     Q_PROPERTY(QString ratio MEMBER m_ratio)
     Q_PROPERTY(QString CRC MEMBER m_CRC)
+    Q_PROPERTY(QString BLAKE2 MEMBER m_BLAKE2)
     Q_PROPERTY(QString method MEMBER m_method)
     Q_PROPERTY(QString version MEMBER m_version)
     Q_PROPERTY(QDateTime timestamp MEMBER m_timestamp)
     Q_PROPERTY(bool isDirectory MEMBER m_isDirectory WRITE setIsDirectory)
+    Q_PROPERTY(bool isExecutable MEMBER m_isExecutable WRITE setIsExecutable)
     Q_PROPERTY(bool isPasswordProtected MEMBER m_isPasswordProtected)
 
 public:
@@ -87,6 +89,8 @@ public:
     QString name() const;
     void setIsDirectory(const bool isDirectory);
     bool isDir() const;
+    void setIsExecutable(const bool isExecutable);
+    bool isExecutable() const;
     int row() const;
     Entry *find(const QString &name) const;
     Entry *findByPath(const QStringList & pieces, int index = 0) const;
@@ -117,10 +121,12 @@ private:
     QString m_link;
     QString m_ratio;
     QString m_CRC;
+    QString m_BLAKE2;
     QString m_method;
     QString m_version;
     QDateTime m_timestamp;
     bool m_isDirectory;
+    bool m_isExecutable;
     bool m_isPasswordProtected;
 };
 
