@@ -320,7 +320,7 @@ void LoadJob::onNewEntry(const Archive::Entry *entry)
 
     if (m_isSingleFolderArchive) {
         // RPM filenames have the ./ prefix, and "." would be detected as the subfolder name, so we remove it.
-        const QString fullPath = entry->fullPath().replace(QRegularExpression(QStringLiteral("^\\./")), QString());
+        const QString fullPath = entry->fullPath().remove(QRegularExpression(QStringLiteral("^\\./")));
         const QString basePath = fullPath.split(QLatin1Char('/')).at(0);
 
         if (m_basePath.isEmpty()) {
@@ -428,13 +428,13 @@ void BatchExtractJob::setupDestination()
     const bool isSingleFolderRPM = (archive()->isSingleFolder() &&
                                    (archive()->mimeType().name() == QLatin1String("application/x-rpm")));
 
-    if (m_autoSubfolder && (!archive()->isSingleFolder() || isSingleFolderRPM)) {
+    if (m_autoSubfolder && (archive()->hasMultipleTopLevelEntries() || isSingleFolderRPM)) {
         const QDir d(m_destination);
         QString subfolderName = archive()->subfolderName();
 
         // Special case for single folder RPM archives.
         // We don't want the autodetected folder to have a meaningless "usr" name.
-        if (isSingleFolderRPM && subfolderName == QStringLiteral("usr")) {
+        if (isSingleFolderRPM && subfolderName == QLatin1String("usr")) {
             qCDebug(ARK) << "Detected single folder RPM archive. Using archive basename as subfolder name";
             subfolderName = QFileInfo(archive()->fileName()).completeBaseName();
         }
