@@ -61,6 +61,7 @@ ArchiveModel::ArchiveModel(const QString &dbusPathName, QObject *parent)
         { Group, "group" },
         { Ratio, "ratio" },
         { CRC, "CRC" },
+        { BLAKE2, "BLAKE2" },
         { Method, "method" },
         { Version, "version" },
         { Timestamp, "timestamp" },
@@ -184,7 +185,9 @@ QVariant ArchiveModel::headerData(int section, Qt::Orientation, int role) const
         case Permissions:
             return i18nc("File permissions", "Mode");
         case CRC:
-            return i18nc("CRC hash code", "CRC");
+            return i18nc("CRC hash code", "CRC checksum");
+        case BLAKE2:
+            return i18nc("BLAKE2 hash code", "BLAKE2 checksum");
         case Method:
             return i18nc("Compression method", "Method");
         case Version:
@@ -311,6 +314,10 @@ bool ArchiveModel::dropMimeData(const QMimeData *data, Qt::DropAction action, in
     QStringList paths;
     const auto urls = data->urls();
     for (const QUrl &url : urls) {
+        if (!url.isLocalFile()) {
+            emit messageWidget(KMessageWidget::Error, i18n("You can only add local files to an archive."));
+            return false;
+        }
         paths << url.toLocalFile();
     }
 
@@ -467,7 +474,7 @@ void ArchiveModel::newEntry(Archive::Entry *receivedEntry, InsertBehaviour behav
     }
 
     // If there are no columns registered, then populate columns from entry. If the first entry
-    // is a directory we check again for the first file entry to ensure all relevent columms are shown.
+    // is a directory we check again for the first file entry to ensure all relevant columms are shown.
     if (m_showColumns.isEmpty() || !m_fileEntryListed) {
         QList<int> toInsert;
 
