@@ -27,6 +27,8 @@
 
 #include "overwritedialog.h"
 
+#include <KLocalizedString>
+
 using namespace Kerfuffle;
 
 OverwriteDialog::OverwriteDialog(QWidget *parent, const QList<const Archive::Entry*> &entries, const QHash<QString, QIcon> &icons, bool error)
@@ -51,7 +53,7 @@ OverwriteDialog::OverwriteDialog(QWidget *parent, const QList<const Archive::Ent
     connect(&m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
     connect(&m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
-    foreach (const Archive::Entry *entry, entries) {
+    for (const Archive::Entry *entry : entries) {
         QListWidgetItem *item = new QListWidgetItem(icons.value(entry->fullPath(NoTrailingSlash)), entry->fullPath(NoTrailingSlash));
         m_entriesList.addItem(item);
     }
